% computes the steady state of fs2000 analyticaly
% largely inspired by the program of F. Schorfheide
function [ys,check] = scaled_steadystate(ys)
  % Inputs:
  %   ys: initial values declared in INITVAL in alphabetical order of the
  %       variables
  % Ouputs:
  %   ys: computed steady state values in alphabetical order of the
  %       variables
  %   check: steady state OK=0; problem in computing steady state = 1 
  % Structural parameters of the model are declared as global  
  global beta_p chi_p le_p delta_p el theta_p ...
           kpshr_p nu_p s_p chi0_p rhon_p rhom_p omega rhoc nfa_p;

  check = 0;
  
  
% net foreign assets
nfa =0;

tby = 0;

% net foreign assets to gdp
nfay = 0;

% consumption based-real exchange rate
q = 1;

% saving rate
sy = s_p;

% investment rate
ipy = s_p;

% short term real rate
rs = 1/beta_p -1;

% Labor
le = le_p;

% Output
gdp = le_p*(1-nu_p*(s_p/(delta_p))^(1-theta_p))^(1/(theta_p-1));

% Investment
ip = (s_p * gdp);

% Consumption
cc = (gdp - ip);

% domestic part of consumption
ccd = omega*cc;

ccm = (1-omega)*cc;

pf = 1;

pc = 1;

% Capital 
kp = ip/delta_p;

% Rental rate for capital
rk = (delta_p - 1 + 1/beta_p);

% Rental rate for labor
rw = (gdp/le)^theta_p;

% Marginal utility of consumption
lambda = 1/cc;

% GAMMA: Marginal utility of capital
gamma = lambda;

% Labor-augmenting technology
mun=1;

% Capital-augmenting technology
m=0;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%/
% Steady state for country 2
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%/
rs2 = 1/beta_p -1;

% trade balance
tby2 = 0;

% Consumption-based real exchange rate
q2 = 1;

% Labor
le2 = le_p;

% Output
gdp2 = le_p*(1-nu_p*(s_p/(delta_p))^(1-theta_p))^(1/(theta_p-1));

% Investment
ip2 = (s_p * gdp);

% Consumption
cc2 = (gdp - ip);

% domestic part of consumption
ccd2 = omega*cc2;

ccm2 = (1-omega)*cc2;

pf2 = 1;

pc2 = 1;

% Capital 
kp2 = ip/delta_p;

% Rental rate for capital
rk2 = (delta_p - 1 + 1/beta_p);

% Rental rate for labor
rw2 = (gdp/le)^theta_p;

% Marginal utility of consumption
lambda2 = 1/cc2;

% GAMMA: Marginal utility of capital
gamma2 = lambda2;

% Relative technology size
n2reln = 1;

% Labor-augmenting technology
mun2=1;

% Capital-augmenting technology
m2=0;



  
  ys =[cc     
cc2    
ccd    
ccd2   
ccm    
ccm2   
gamma  
gamma2 
gdp    
gdp2   
ip     
ip2    
ipy    
kp     
kp2    
lambda 
lambda2
le     
le2    
m      
m2     
mun    
mun2   
n2reln 
nfa    
nfay   
pc     
pc2    
pf     
pf2    
q      
q2     
rk     
rk2    
rs     
rs2    
rw     
rw2    
sy     
tby    
tby2];