// RBC model 
// with variable labor

var cc, le, lambda, gamma, gdp, ip ,kp, rw, rk, mun, m, rs, ccd, ccm, pf, pc, nfa, nfay, tby, q, sy, ipy
    cc2, le2, lambda2, gamma2, gdp2, ip2 ,kp2, rw2, rk2, mun2, m2, ccd2, ccm2, pf2, pc2, rs2, tby2, q2, n2reln;

varexo nerr, merr, nerr2, merr2;

// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
// % define parameters here
// %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

parameters beta_p, chi_p, le_p, delta_p, el, theta_p, phic_p
           kpshr_p, nu_p, s_p, chi0_p, rhon_p, rhom_p, omega, rhoc, nfa_p, pop2relpop_p, omega2;


param;

pop2relpop_p = 1;

omega2 = 1-(1-omega)/pop2relpop_p;

phic_p = 0.8;
  
model;
///////////////////////////////////////////////////////////////////////////
// Country 1
///////////////////////////////////////////////////////////////////////////

// FOC with respect to consumption
(1-phic_p)/(cc-phic_p*cc(-1)) - lambda*pc=0;   

// FOC wrt Labor
-chi0_p*(1-le)^(-chi_p) + lambda * rw =0;

// Lambda Marginal Utility of consumption
gamma-lambda = 0;

// gamma shadow price of capital
(1-delta_p)*beta_p * gamma(1)/mun(1) - gamma +beta_p *lambda(1)/mun(1)*rk(1) = 0;

// Aggregate Output
gdp = (nu_p*(kp(-1)*exp(m)/mun)^(1-theta_p) + (le)^(1-theta_p))^(1/(1-theta_p));

// resource constraint
gdp = ccd + ip + ccm2*n2reln*pop2relpop_p;


// definition of consumption aggregator (pins down ccd)
cc = (omega^(rhoc/(1+rhoc))*ccd^(1/(1+rhoc))+(1-omega)^(rhoc/(1+rhoc))*ccm^(1/(1+rhoc)))^(1+rhoc);


// import demand
ccm = (1-omega)*(pf/pc)^(-(1+rhoc)/rhoc) * cc;

// consumption prices
pc = (omega+(1-omega)*pf^(-1/rhoc))^(-rhoc);

// nfa
pf*nfa/(1+rs2)/exp(-nfa_p/2*(pf*nfa/gdp)) = pf*(nfa(-1))/mun + ccm2*n2reln*pop2relpop_p-pf*ccm ;

// nfa to gdp
nfay = pf*nfa/gdp;

// Trade Balance, share of GDP
tby = (ccm2*n2reln*pop2relpop_p-pf*ccm)/gdp;

// Saving rate
sy = 1-cc/gdp;

// Investment rate
ipy = ip/gdp;

// UIP equation
1/(1+rs)*pf(1)/pf = 1/(1+rs2)/exp(-nfa_p/2*(pf*nfa/gdp)) ;

// This is the home risk-free rate.
1/(1+rs) = beta_p *lambda(1)/lambda/mun(1);

// Consumption-based real exchange rate
q = pf*pc2/pc;

// Capital
kp = (1-delta_p)*kp(-1)/mun + ip;

// Rental Rate for Labor, FOC with respect to labor
rw = (gdp/le)^(theta_p);

// Rental Rate for Capital
rk = nu_p*(gdp/(kp(-1)*exp(m))*mun)^theta_p * exp(m);

// Technology level in country 2 relative to the home contry
n2reln = mun2/mun *n2reln(-1);

// Labor-augmenting technology shock
mun -1 = rhon_p*(mun(-1)-1) + nerr;

// Capital Augmenting Technology Shock
m = rhom_p*m(-1) + merr;

///////////////////////////////////////////////////////////////////////////
// Country 2
///////////////////////////////////////////////////////////////////////////

// FOC with respect to consumption
(1-phic_p)/(cc2-phic_p*cc2(-1)) - lambda2*pc2=0;   

// FOC wrt Labor
-chi0_p*(1-le2)^(-chi_p) + lambda2 * rw2 =0;

// Lambda Marginal Utility of consumption
gamma2-lambda2 = 0;

// gamma shadow price of capital
(1-delta_p)*beta_p * gamma2(1)/mun2(1) - gamma2 +beta_p *lambda2(1)/mun2(1)*rk2(1) = 0;

// Aggregate Output
gdp2 = (nu_p*(kp2(-1)*exp(m2)/mun2)^(1-theta_p) + (le2)^(1-theta_p))^(1/(1-theta_p));

// resource constraint
gdp2= ip2 + ccd2 + ccm/n2reln/pop2relpop_p;

// definition of consumption aggregator (pins down ccd)
cc2 = (omega2^(rhoc/(1+rhoc))*ccd2^(1/(1+rhoc))+(1-omega2)^(rhoc/(1+rhoc))*ccm2^(1/(1+rhoc)))^(1+rhoc);

//ccd2 = omega2*(1/pc2)^(-(1+rhoc)/rhoc) *cc2;

// import demand
ccm2 = (1-omega2)*(pf2/pc2)^(-(1+rhoc)/rhoc) * cc2;

pc2 = (omega2+(1-omega2)*pf2^(-1/rhoc))^(-rhoc);

pf2 = 1/pf;

// Trade Balance (share of GDP)
tby2 = (ccm/n2reln/pop2relpop_p-pf2*ccm2)/gdp2;

1/(1+rs2) = beta_p *lambda2(1)/lambda2/mun2(1);

// Capital
kp2 = (1-delta_p)*kp2(-1)/mun2 + ip2;

// Rental Rate for Labor, FOC with respect to labor
rw2 = (gdp2/le2)^(theta_p);

// Rental Rate for Capital
rk2 = nu_p*(gdp2/(kp2(-1)*exp(m2))*mun2)^theta_p * exp(m2);

// Consumption-based real exchange rate
q2 = 1/q;

// Labor-augmenting technology shock
mun2-1 = rhon_p*(mun2(-1)-1) + nerr2;

// Capital Augmenting Technology Shock
m2 = rhom_p*m2(-1) + merr2;

end;


// Steady state values

initval;

///////////////////////////////////////////////////////////////////////////
// Steady state for  country 1
///////////////////////////////////////////////////////////////////////////

// net foreign assets
nfa =0;

// net foreign assets to gdp
nfay = 0;

// consumption based-real exchange rate
q = 1;

// saving rate
sy = s_p;

// investment rate
ipy = s_p;

// short term real rate
rs = 1/beta_p -1;

// Labor
le = le_p;

// Output
gdp = le_p*(1-nu_p*(s_p/(delta_p))^(1-theta_p))^(1/(theta_p-1));

// Investment
ip = (s_p * gdp);

// Consumption
cc = (gdp - ip);

// domestic part of consumption
ccd = omega*cc;

ccm = (1-omega)*cc;

pf = 1;

pc = 1;

// Capital 
kp = ip/delta_p;

// Rental rate for capital
rk = (delta_p - 1 + 1/beta_p);

// Rental rate for labor
rw = (gdp/le)^theta_p;

// Marginal utility of consumption
lambda = 1/cc;

// GAMMA: Marginal utility of capital
gamma = lambda;

// tby = 0;

// Labor-augmenting technology
mun=1;

// Capital-augmenting technology
m=0;

///////////////////////////////////////////////////////////////////////////
// Steady state for country 2
///////////////////////////////////////////////////////////////////////////
rs2 = 1/beta_p -1;

tby2 = 0;

// Consumption-based real exchange rate
q2 = 1;

// Labor
le2 = le_p;

// Output
gdp2 = le_p*(1-nu_p*(s_p/(delta_p))^(1-theta_p))^(1/(theta_p-1));

// Investment
ip2 = (s_p * gdp);

// Consumption
cc2 = (gdp - ip);

// domestic part of consumption
ccd2 = omega2*cc2;

ccm2 = (1-omega2)*cc2;

pf2 = 1;

pc2 = 1;

// Capital 
kp2 = ip/delta_p;

// Rental rate for capital
rk2 = (delta_p - 1 + 1/beta_p);

// Rental rate for labor
rw2 = (gdp/le)^theta_p;

// Marginal utility of consumption
lambda2 = 1/cc2;

// GAMMA: Marginal utility of capital
gamma2 = lambda2;

// Relative technology size
n2reln = 1;

// Labor-augmenting technology
mun2=1;

// Capital-augmenting technology
m2=0;



end;

shocks;
var nerr; stderr .01;
var merr; stderr .01;
var merr2; stderr .01;
var nerr2; stderr .01;
end;

check;

stoch_simul(order=1,nocorr,nomoments,irf=0);

//stoch_simul(order=1,nocorr,nomoments,noprint,irf=0);
